{% extends 'helpdesk/base.html' %}
{% load bootstrap3 %}

{% block content %}
    <div class="row">
        <div class="col-xs-12">
            <div class="row">
                <div class="col-lg-6 col-lg-offset-3">
                    <div class="well">
                        <h2>Create new ticket</h2>

                        <p class="alert alert-info">Ticket will be created and comment will be sent to user.</p>

                        <form method="post" enctype="multipart/form-data">
                            {% csrf_token %}
                            {% bootstrap_form form %}

                            {{ attachment_formset.management_form }}
                            {% for form in attachment_formset %}
                                {% bootstrap_form form %}
                            {% endfor %}

                            {% bootstrap_button 'Create and send' button_type='submit' %}
                        </form>
                    </div>
                </div>
            </div>


        </div>
    </div>
{% endblock %}