{% load helpdesk %}
<div class="list-group">
    {% for ticket in object_list %}
        <div class="list-group-item">
            <div class="row-action-primary">
                <i class="mdi-file-folder"></i>
            </div>
            <div class="row-content">
                <h4 class="list-group-item-heading single-line">
                    <a href="{{ ticket.get_absolute_url }}"
                       title="{{ ticket.title }}">HD-{{ ticket.pk }} {{ ticket.title }}</a>
                </h4>

                <div class="list-group-item-text">
                    <div class="row">
                        <div class="col-xs-2">
                            {{ ticket.priority_label }}
                        </div>
                        <div class="col-xs-2">
                            {{ ticket.state.label }}
                        </div>
                        <div class="col-xs-2">
                                        <span class="label"
                                              title="Updated">{{ ticket.updated|date:"d.m.Y H:i:s" }}</span>
                        </div>
                        <div class="col-xs-2">
                            <span class="label">{{ ticket.project|default:"" }}</span>
                        </div>
                        <div class="col-xs-2">
                                        <span class="label {% if ticket.assignee == request.user %}label-success{% endif %}">
                                            {% assignee ticket %}
                                        </span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="list-group-separator"></div>
    {% endfor %}
</div>