{% load staticfiles %}
<html>

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <link href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css" rel="stylesheet">
    <link href="{% static 'helpdesk/css/ripples.min.css' %}" rel="stylesheet">
    <link href="{% static 'helpdesk/css/material-wfont.min.css' %}" rel="stylesheet">
    <link href="{% static 'helpdesk/css/jquery.dropdown.css' %}" rel="stylesheet">
    <link href="{% static 'helpdesk/css/custom.css' %}?v3" rel="stylesheet">
</head>

<body>
<div class="navbar navbar-default">
    <div class="navbar-header">
        <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-responsive-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
        </button>
        <a class="navbar-brand" href="{% url 'helpdesk_home' %}">HelpDesk</a>
    </div>

    <div class="navbar-collapse collapse navbar-responsive-collapse">
        <ul class="nav navbar-nav">
            {% include 'helpdesk/menu.html' %}
        </ul>
    </div>
</div>

<div class="container-fluid">
    {% block content %}{% endblock %}
</div>

<script src="//code.jquery.com/jquery-1.10.2.min.js"></script>
<script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>

<script src="{% static 'helpdesk/js/ripples.min.js' %}"></script>
<script src="{% static 'helpdesk/js/material.min.js' %}"></script>
<script src="{% static 'helpdesk/js/jquery.dropdown.js' %}"></script>
<script src="{% static 'helpdesk/js/custom.js' %}"></script>

<script type="text/javascript" src="{% static "ckeditor/ckeditor/ckeditor.js" %}"></script>
<script type="text/javascript" src="{% static "ckeditor/ckeditor-init.js" %}"></script>
<script>
    $(document).ready(function () {
        $.material.init();
    });
</script>

</body>

</html>
