{% load i18n %}
{% language 'ru' %}
<p>Hi {{ ticket.assignee.username }},</p>

<p>An issue <a href="{{ ticket.get_full_url }}">{{ ticket.title }}</a> was updated by {{ updater.username }}:</p>

<ul>
    {% for change in changes %}<li>{{ change }}</li>{% endfor %}
</ul>
{% endlanguage %}