.table-info>tbody>tr:first-child>th,
.table-info>tbody>tr:first-child>td {
    border-top: none;
}

.label {
    display: inline-block;
}

.single-line {
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden;
    width: 100%;
}

.history-list {
    font-size: small;
    color: #777;
}

.history-list li {
    padding-bottom: 5px;
}

.django-ckeditor-widget {
    width: 100%;
}

.help-block {
    font-size: smaller;
}

.ticket-compact-list li {

}

.ticket-compact-list li .label {
    vertical-align: top;
}

.ticket-compact-list li a {
    display: block;
    padding-bottom: 10px;
    padding-top: 10px;
    border-bottom: 1px solid rgba(0,0,0,.1);
}

.ticket-compact-list li.resolved span {
    opacity: .4;
}

.ticket-compact-list li a:hover,
.ticket-compact-list li a:focus,
.ticket-compact-list li a:active {
    text-decoration: none;
    background: rgba(0,0,0,.1);
}

.label-no-bg {
    background: none;
    color: #333;
}

.search-form .form-group {
    margin: 0;
}

.search-form .btn {
    margin: 0;
    padding: 5px 30px;
}