<html>

    <head>

        <link href="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/css/bootstrap.min.css" rel="stylesheet">
        <link href="{{ STATIC_URL }}css/ripples.min.css" rel="stylesheet">
        <link href="{{ STATIC_URL }}css/material-wfont.min.css" rel="stylesheet">

    </head>

    <body>

        <!-- Your site -->

        <h1>You can add your site here.</h1>

        <h2>To ensure that material-design theme is working, check out the buttons below.</h2>

        <h3 class="text-muted">If you can see the ripple effect on clicking them, then you are good to go!</h3>


        <p class="bs-component">
            <a href="javascript:void(0)" class="btn btn-default">Default</a>
            <a href="javascript:void(0)" class="btn btn-primary">Primary</a>
            <a href="javascript:void(0)" class="btn btn-success">Success</a>
            <a href="javascript:void(0)" class="btn btn-info">Info</a>
            <a href="javascript:void(0)" class="btn btn-warning">Warning</a>
            <a href="javascript:void(0)" class="btn btn-danger">Danger</a>
            <a href="javascript:void(0)" class="btn btn-link">Link</a>
        </p>

        <!-- Your site ends -->

        <script src="//code.jquery.com/jquery-1.10.2.min.js"></script>
        <script src="//maxcdn.bootstrapcdn.com/bootstrap/3.2.0/js/bootstrap.min.js"></script>

        <script src="{{ STATIC_URL }}js/ripples.min.js"></script>
        <script src="{{ STATIC_URL }}js/material.min.js"></script>
        <script>
            $(document).ready(function() {
                $.material.init();
            });
        </script>

    </body>

</html>
